@@ -3,6 +3,7 @@ import astropy.wcs as pywcs
 import os
 from collections import defaultdict
 from regions import PixCoord
+import warnings
 
 from soxs.events import write_event_file
 from soxs.instrument_registry import instrument_registry
@@ -317,8 +318,8 @@ def generate_events(source, exp_time, instrument, sky_center,
 def make_background(exp_time, instrument, sky_center, foreground=True,
                     ptsrc_bkgnd=True, instr_bkgnd=True, no_dither=False,
                     dither_params=None, roll_angle=0.0, subpixel_res=False,
-                    input_sources=None, absorb_model="wabs", nH=0.05, 
-                    aimpt_shift=None, prng=None):
+                    input_pt_sources=None, aimpt_shift=None, prng=None,
+                    **kwargs):
     """
     Make background events.
 
@@ -345,21 +346,15 @@ def make_background(exp_time, instrument, sky_center, foreground=True,
         Default: [8.0, 8.0, 1000.0, 707.0].
     ptsrc_bkgnd : boolean, optional
         Whether or not to include the point-source background. Default: True
-        Default: 0.05
     roll_angle : float, (value, unit) tuple, or :class:`~astropy.units.Quantity`, optional
         The roll angle of the observation in degrees. Default: 0.0
     subpixel_res: boolean, optional
         If True, event positions are not randomized within the pixels 
         within which they are detected. Default: False
-    input_sources : string, optional
+    input_pt_sources : string, optional
         If set to a filename, input the point source positions, fluxes,
         and spectral indices from an ASCII table instead of generating
         them. Default: None
-    absorb_model : string, optional
-        The absorption model to use, "wabs" or "tbabs". Default: "wabs"
-    nH : float, optional
-        The hydrogen column in units of 10**22 atoms/cm**2. 
-        Default: 0.05
     aimpt_shift : array-like, optional
         A two-float array-like object which shifts the aimpoint on the 
         detector from the nominal position. Units are in arcseconds.
@@ -370,6 +365,13 @@ def make_background(exp_time, instrument, sky_center, foreground=True,
         set of random numbers, such as for a test. Default is None, 
         which sets the seed based on the system time. 
     """
+    if "nH" in kwargs or "absorb_model" in kwargs:
+        warnings.warn("The 'nH' and 'absorb_model' keyword arguments"
+                      "have been omitted. Please set the 'bkgnd_nH' "
+                      "and 'bkgnd_absorb_model' values in the SOXS"
+                      "configuration file if you want to change these "
+                      "values. ",
+                      DeprecationWarning)
     from soxs.background import make_instrument_background, \
         make_foreground, make_ptsrc_background
     prng = parse_prng(prng)
@@ -396,9 +398,8 @@ def make_background(exp_time, instrument, sky_center, foreground=True,
         mylog.info("Adding in point-source background.")
         ptsrc_events = make_ptsrc_background(exp_time, fov, sky_center,
                                              area=1.2*arf.max_area,
-                                             input_sources=input_sources,
-                                             absorb_model=absorb_model,
-                                             nH=nH, prng=prng)
+                                             input_sources=input_pt_sources,
+                                             prng=prng)
         for key in ["ra", "dec", "energy"]:
             input_events[key].append(ptsrc_events[key])
         input_events["flux"].append(ptsrc_events["flux"])
@@ -475,8 +476,8 @@ def make_background(exp_time, instrument, sky_center, foreground=True,
 def make_background_file(out_file, exp_time, instrument, sky_center,
                          overwrite=False, foreground=True, instr_bkgnd=True,
                          ptsrc_bkgnd=True, no_dither=False, dither_params=None,
-                         subpixel_res=False, input_sources=None, 
-                         absorb_model="wabs", nH=0.05, prng=None):
+                         subpixel_res=False, input_pt_sources=None, 
+                         prng=None, **kwargs):
     """
     Make an event file consisting entirely of background events. This will be 
     useful for creating backgrounds that can be added to simulations of sources.
@@ -510,21 +511,28 @@ def make_background_file(out_file, exp_time, instrument, sky_center,
     subpixel_res: boolean, optional
         If True, event positions are not randomized within the pixels 
         within which they are detected. Default: False
-    input_sources : string, optional
+    input_pt_sources : string, optional
         If set to a filename, input the point source positions, fluxes,
         and spectral indices from an ASCII table instead of generating
         them. Default: None
-    absorb_model : string, optional
-        The absorption model to use, "wabs" or "tbabs". Default: "wabs"
-    nH : float, optional
-        The hydrogen column in units of 10**22 atoms/cm**2. 
-        Default: 0.05
     prng : :class:`~numpy.random.RandomState` object, integer, or None
         A pseudo-random number generator. Typically will only 
         be specified if you have a reason to generate the same 
         set of random numbers, such as for a test. Default is None, 
         which sets the seed based on the system time. 
     """
+    if "nH" in kwargs or "absorb_model" in kwargs:
+        warnings.warn("The 'nH' and 'absorb_model' keyword arguments"
+                      "have been omitted. Please set the 'bkgnd_nH' "
+                      "and 'bkgnd_absorb_model' values in the SOXS"
+                      "configuration file if you want to change these "
+                      "values. ",
+                      DeprecationWarning)
+    if "input_sources" in kwargs:
+        warnings.warn("The 'input_sources' keyword argument has been changed "
+                      "to 'input_pt_sources' and is deprecated.", 
+                      DeprecationWarning)
+        input_pt_sources = kwargs.pop("input_sources")
     prng = parse_prng(prng)
     events, event_params = make_background(exp_time, instrument, sky_center, 
                                            ptsrc_bkgnd=ptsrc_bkgnd, 
@@ -533,9 +541,8 @@ def make_background_file(out_file, exp_time, instrument, sky_center,
                                            no_dither=no_dither,
                                            dither_params=dither_params, 
                                            subpixel_res=subpixel_res,
-                                           input_sources=input_sources,
-                                           absorb_model=absorb_model,
-                                           nH=nH, prng=prng)
+                                           input_pt_sources=input_pt_sources,
+                                           prng=prng)
     write_event_file(events, event_params, out_file, overwrite=overwrite)
 
 
@@ -545,7 +552,7 @@ def instrument_simulator(input_events, out_file, exp_time, instrument,
                          bkgnd_file=None, no_dither=False, 
                          dither_params=None, roll_angle=0.0, 
                          subpixel_res=False, aimpt_shift=None,
-                         prng=None):
+                         input_pt_sources=None, prng=None):
     """
     Take unconvolved events and create an event file from them. This
     function calls generate_events to do the following:
@@ -611,6 +618,10 @@ def instrument_simulator(input_events, out_file, exp_time, instrument,
         A two-float array-like object which shifts the aimpoint on the 
         detector from the nominal position. Units are in arcseconds.
         Default: None, which results in no shift from the nominal aimpoint. 
+    input_pt_sources : string, optional
+        If set to a filename, input the point source positions, fluxes,
+        and spectral indices from an ASCII table instead of generating
+        them. Default: None
     prng : :class:`~numpy.random.RandomState` object, integer, or None
         A pseudo-random number generator. Typically will only 
         be specified if you have a reason to generate the same 
@@ -642,8 +653,8 @@ def instrument_simulator(input_events, out_file, exp_time, instrument,
                 exp_time, instrument, sky_center, foreground=foreground,
                 instr_bkgnd=instr_bkgnd, no_dither=no_dither,
                 dither_params=dither_params, ptsrc_bkgnd=ptsrc_bkgnd, prng=prng,
-                subpixel_res=subpixel_res, roll_angle=roll_angle, 
-                aimpt_shift=aimpt_shift)
+                subpixel_res=subpixel_res, roll_angle=roll_angle,
+                aimpt_shift=aimpt_shift, input_pt_sources=input_pt_sources)
             for key in events:
                 events[key] = np.concatenate([events[key], bkg_events[key]])
     else:
@@ -652,16 +663,17 @@ def instrument_simulator(input_events, out_file, exp_time, instrument,
             raise IOError(f"Cannot find the background event file {bkgnd_file}!")
         events = add_background_from_file(events, event_params, bkgnd_file)
     if len(events["energy"]) == 0:
-        raise RuntimeError("No events were detected from source or background!!")
-    write_event_file(events, event_params, out_file, overwrite=overwrite)
+        mylog.warning("No events were detected from source or background!! We "
+                      "will not write an event file.")
+    else:
+        write_event_file(events, event_params, out_file, overwrite=overwrite)
     mylog.info("Observation complete.")
 
 
 def simulate_spectrum(spec, instrument, exp_time, out_file,
                       instr_bkgnd=False, foreground=False,
                       ptsrc_bkgnd=False, bkgnd_area=None,
-                      absorb_model="wabs", nH=0.05,
-                      overwrite=False, prng=None):
+                      overwrite=False, prng=None, **kwargs):
     """
     Generate a PI or PHA spectrum from a :class:`~soxs.spectra.Spectrum`
     by convolving it with responses. To be used if one wants to 
@@ -693,11 +705,6 @@ def simulate_spectrum(spec, instrument, exp_time, out_file,
         The area on the sky for the background components, in square arcminutes.
         Default: None, necessary to specify if any of the background components
         are turned on. 
-    absorb_model : string, optional
-        The absorption model to use, "wabs" or "tbabs". Default: "wabs"
-    nH : float, optional
-        The hydrogen column in units of 10**22 atoms/cm**2. 
-        Default: 0.05
     overwrite : boolean, optional
         Whether or not to overwrite an existing file. Default: False
     prng : :class:`~numpy.random.RandomState` object, integer, or None
@@ -716,9 +723,17 @@ def simulate_spectrum(spec, instrument, exp_time, out_file,
     from soxs.response import RedistributionMatrixFile, \
         AuxiliaryResponseFile
     from soxs.spectra import ConvolvedSpectrum
-    from soxs.background.foreground import hm_astro_bkgnd
+    from soxs.background.foreground import frgnd_spec
     from soxs.background.spectra import BackgroundSpectrum
     from soxs.background.instrument import InstrumentalBackground
+    from soxs.utils import soxs_cfg
+    if "nH" in kwargs or "absorb_model" in kwargs:
+        warnings.warn("The 'nH' and 'absorb_model' keyword arguments"
+                      "have been omitted. Please set the 'bkgnd_nH' "
+                      "and 'bkgnd_absorb_model' values in the SOXS"
+                      "configuration file if you want to change these "
+                      "values. ",
+                      DeprecationWarning)
     prng = parse_prng(prng)
     exp_time = parse_value(exp_time, "s")
     try:
@@ -757,7 +772,8 @@ def simulate_spectrum(spec, instrument, exp_time, out_file,
 
     if foreground:
         mylog.info("Adding in astrophysical foreground.")
-        cspec_frgnd = ConvolvedSpectrum.convolve(hm_astro_bkgnd.to_spectrum(fov), arf)
+        cspec_frgnd = ConvolvedSpectrum.convolve(
+            frgnd_spec.to_spectrum(fov), arf)
         out_spec += rmf.convolve_spectrum(cspec_frgnd, exp_time, prng=prng)
     if instr_bkgnd and instrument_spec["bkgnd"] is not None:
         mylog.info("Adding in instrumental background.")
@@ -772,9 +788,11 @@ def simulate_spectrum(spec, instrument, exp_time, out_file,
                                                          prng=prng)
     if ptsrc_bkgnd:
         mylog.info("Adding in background from unresolved point-sources.")
-        spec_plaw = BackgroundSpectrum.from_powerlaw(1.45, 0.0, 2.0e-7, emin=0.01,
+        bkgnd_nH = float(soxs_cfg.get("soxs", "bkgnd_nH"))
+        absorb_model = soxs_cfg.get("soxs", "bkgnd_absorb_model")
+        spec_plaw = BackgroundSpectrum.from_powerlaw(1.52, 0.0, 2.0e-7, emin=0.01,
                                                      emax=10.0, nbins=300000)
-        spec_plaw.apply_foreground_absorption(nH, model=absorb_model)
+        spec_plaw.apply_foreground_absorption(bkgnd_nH, model=absorb_model)
         cspec_plaw = ConvolvedSpectrum.convolve(spec_plaw.to_spectrum(fov), arf)
         out_spec += rmf.convolve_spectrum(cspec_plaw, exp_time, prng=prng)
 
