@@ -6,6 +6,7 @@ from soxs.spatial import construct_wcs
 from astropy.units import Quantity
 from collections.abc import Sequence
 import os
+from pathlib import Path
 
 
 def _parse_catalog_entry(src):
@@ -283,14 +284,22 @@ class SimputCatalog:
         if src_filename == self.filename:
             # Don't overwrite the SIMPUT catalog file!!
             overwrite = False
+        elif overwrite and os.path.exists(src_filename):
+            mylog.warning(f"Overwriting {src_filename}.")
+            os.remove(src_filename)
 
         extver = _determine_extver(src_filename, source.src_type.upper())
-        spec_fn = src_filename if src_filename != self.filename else ""
-        spec = f"{spec_fn}[{source.src_type.upper()},{extver}]"
+        if src_filename != self.filename:
+            src_fn = os.path.join(
+                os.path.relpath(Path(src_filename).parent,
+                                Path(self.filename).parent),
+                os.path.basename(src_filename))
+        else:
+            src_fn = ""
+        spec = f"{src_fn}[{source.src_type.upper()},{extver}]"
         if source.imhdu is not None:
             img_extver = _determine_extver(src_filename, "IMAGE")
-            img_fn = src_filename if src_filename != self.filename else ""
-            img = f"{img_fn}[IMAGE,{img_extver}]"
+            img = f"{src_fn}[IMAGE,{img_extver}]"
         elif source.src_type == "phlist":
             img = spec
             img_extver = extver
