@@ -9,8 +9,7 @@ from soxs.utils import soxs_files_path, mylog, \
 from soxs.lib.broaden_lines import broaden_lines
 from soxs.constants import erg_per_keV, hc, \
     cosmic_elem, metal_elem, atomic_weights, clight, \
-    m_u, elem_names, sigma_to_fwhm, abund_tables, sqrt2pi, \
-    default_apec_vers
+    m_u, elem_names, sigma_to_fwhm, abund_tables, sqrt2pi
 import astropy.io.fits as pyfits
 import astropy.units as u
 import h5py
@@ -73,6 +72,11 @@ class Spectrum:
         self._check_binning_units(other)
         return Spectrum(self.ebins, self.flux+other.flux)
 
+    def __iadd__(self, other):
+        self._check_binning_units(other)
+        self.flux += other.flux
+        return self
+
     def __sub__(self, other):
         self._check_binning_units(other)
         return Spectrum(self.ebins, self.flux-other.flux)
@@ -260,11 +264,10 @@ class Spectrum:
             The path to the file containing the spectrum.
         """
         if filename.endswith(".h5"):
-            f = h5py.File(filename, "r")
-            flux = f["spectrum"][()]
-            nbins = flux.size
-            ebins = np.linspace(f["emin"][()], f["emax"][()], nbins+1)
-            f.close()
+            with h5py.File(filename, "r") as f:
+                flux = f["spectrum"][()]
+                nbins = flux.size
+                ebins = np.linspace(f["emin"][()], f["emax"][()], nbins+1)
         else:
             emid, flux = np.loadtxt(filename, unpack=True)
             de = np.diff(emid)[0]
@@ -614,8 +617,9 @@ class ApecGenerator:
         are stored. If not provided, the default is to 
         grab them from the tables stored with SOXS.
     apec_vers : string, optional
-        The version identifier string for the APEC files. 
-        Default: "3.0.9"
+        The version identifier string for the APEC files. Default is
+        set in the SOXS configuration file, the default for which is
+        "3.0.9".
     broadening : boolean, optional
         Whether or not the spectral lines should be 
         thermally and velocity broadened. Default: True
@@ -651,8 +655,8 @@ class ApecGenerator:
                  apec_vers=None, broadening=True, nolines=False,
                  abund_table=None, nei=False):
         if apec_vers is None:
-            apec_vers = default_apec_vers
-        mylog.info(f"Using APEC version {apec_vers}.")
+            apec_vers = soxs_cfg.get("soxs", "apec_vers")
+        mylog.debug(f"Using APEC version {apec_vers}.")
         if nei and var_elem is None:
             raise RuntimeError("For NEI spectra, you must specify which elements "
                                "you want to vary using the 'var_elem' argument!")
@@ -682,8 +686,8 @@ class ApecGenerator:
         if not os.path.exists(self.cocofile) or not os.path.exists(self.linefile):
             raise IOError(f"Cannot find the APEC files!\n {self.cocofile}\n, "
                           f"{self.linefile}")
-        mylog.info(f"Using {cocofile} for generating spectral lines.")
-        mylog.info(f"Using {linefile} for generating the continuum.")
+        mylog.debug(f"Using {cocofile} for generating spectral lines.")
+        mylog.debug(f"Using {linefile} for generating the continuum.")
         self.nolines = nolines
         self.wvbins = hc/self.ebins[::-1]
         self.broadening = broadening
@@ -995,6 +999,14 @@ class ConvolvedSpectrum(Spectrum):
             arf = AuxiliaryResponseFile(arf)
         self.arf = arf
 
+    def __add__(self, other):
+        self._check_binning_units(other)
+        return ConvolvedSpectrum(self.ebins, self.flux+other.flux, self.arf)
+
+    def __sub__(self, other):
+        self._check_binning_units(other)
+        return ConvolvedSpectrum(self.ebins, self.flux-other.flux, self.arf)
+
     @classmethod
     def convolve(cls, spectrum, arf):
         """
